
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ FOLDER DEFINITIONS -----------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
from abaqus import *
from abaqusConstants import *
import __main__
import section
import regionToolset
import displayGroupMdbToolset as dgm
import part
import material
import assembly
import step
import interaction
import load
import mesh
import optimization
import job
import sketch
import visualization
import xyPlot
import displayGroupOdbToolset as dgo
import connectorBehavior
import numpy as np
import math
import time

def tic():
    #Homemade version of matlab tic and toc functions
    import time
    global startTime_for_tictoc
    startTime_for_tictoc=time.time()

def toc():
    import time
    if 'startTime_for_tictoc' in globals():
        print "Elapsed time is " + str(time.time() - startTime_for_tictoc) + " seconds."
    else:
        print "Toc: start time not set"
        

# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ INPUT VALUES -----------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# CABLE GEOMETRY [m]
a=718.5                         # Horizontal distance between left tower and anchorage
b=2800.0                        # Length of middle span
c=558.0                         # Horizontal distance between right tower and anchorage
d=400.5                         # Height between left tower and anchorage
f=200.0                         # Height between right tower and anchorage
g=37.0                          # Width between cables at left anchorages
h=37.0                          # Width between cables at midspan
i=37.0                          # Width between cables at right anchorages
k=50.5                          # Width between tower legs at bottom
# GIRDER GEOMETRY [m]
n=21+21.7                       # Height between lowest and highest parts of girder. 
p=15.032                        # Horizontal distance between girders
# TOWER GEOMETRY [m]
e=312.5-29.1                    # Height from tower to midspan of cables. 
m=9.5+7.4                       # Vertical distance between cables and girder at the midspan. 
j=57.5                          # Vertical distance between top point girder and bottom of towers. NB must be either .0 or .5 due to tower list
# NODE SPACING (x-dir) [m]
spacing_side_span=25.0          # Horizontal spacing of cable nodes at outer part of towers
spacing_mid_span=24.0           # Horizontal spacing of cable nodes(hangers) at the midspan
spacing_girder=4.0              # Horizontal spacing of girder nodes
# MESH SEED SIZE [m]
sz_towers=500.0
sz_rigels=1.0
sz_cables=500.0
sz_girder=10.0
sz_hangers=500000.0
sz_coneltowers=500.0
sz_conelgirder=500.0
# GIRDER MATERIAL PROPERTIES
Ematgirder=210e9                # E-modulus steel

#NB maa oppdatere density ogsaa i keywordBlock.replace

# NAME AND DIRECTORY OF JOB 
workDir='xxxx' # Add path to work directory
jobName='Sulafjorden_TD21_S1-G1'


# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TOOLS FOR TIE ----------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------


# GIRDERS
VectorCoordX_girder=np.arange(-int(math.floor(b/2/spacing_mid_span)*spacing_mid_span),int(math.floor(b/2/spacing_mid_span)*spacing_mid_span)+spacing_mid_span,spacing_mid_span)
VectorCoordZ_girder=-n/((b/2)**2)*(VectorCoordX_girder**2)+j+n

# CABLES
VectorCoordX_cable=VectorCoordX_girder
VectorCoordZ_cable=e*VectorCoordX_cable**2/(b/2)**2+m+j+n

# TOWERS
VectorCoordY_tower=np.append(np.linspace(k/2,h/2,(j+n+m+e)/0.5+1),np.linspace(-h/2,-k/2,(j+n+m+e)/0.5+1))
VectorCoordZ_tower=np.append(np.linspace(0,e+m+j+n,(j+n+m+e)/0.5+1),np.linspace(e+m+j+n,0,(j+n+m+e)/0.5+1))

def function_nearest_vertice(part_vertices_obj,coord_xyz_search,tol):

    # Inputs:
    # part_vertices_obj: object, e.g. bridge_part.vertices
    # coord_xyz_search: coordinates, e.g. (0,10,50)
    # tol: distance tolerance for search
    # Outputs:
    # index_match: index of nearest vertice
    # coord_match: coordinates of nearest vertice
    # distance_match: distance to nearest vertice
    # vertice_out: object that can be used as master/slave

    vert_match=part_vertices_obj.getClosest(coordinates=((coord_xyz_search),),searchTolerance=tol)
    vert_match2=part_vertices_obj.findAt(vert_match[0][1])
    index_match=vert_match2.index
    coord_match=vert_match[0][1]
    distance_match=np.linalg.norm(np.asarray(coord_match)-np.asarray(coord_xyz_search))
    
    vertice_out=part_vertices_obj.findAt((part_vertices_obj[index_match].pointOn[0], ) ,)
    
    return index_match,coord_match,distance_match,vertice_out


# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ GENERATING LISTS OF COORDINATES ----------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# CABLES
n_divisions_mid=b/spacing_mid_span
n_divisions_side1=a/spacing_side_span
n_divisions_side2=c/spacing_side_span

x1=np.arange(-b/2, b/2, spacing_mid_span)
if n_divisions_mid%1==0:
    pass
else:
    delay=(b - math.floor(b / spacing_mid_span) * spacing_mid_span) * 0.5
    x1=x1 + delay
    x1=np.append(-b/2, x1)
    x1=np.append(x1, b/2)

y1=-(2*(h-h)/(b*b))*x1*x1+h/2
z1=(4*e/(b*b))*x1*x1+m+j+n

x2=np.arange(-b//2, b//2, spacing_mid_span)
if n_divisions_mid%1==0:
    pass
else:
    delay=(b - math.floor(b / spacing_mid_span) * spacing_mid_span) * 0.5
    x2=x2 + delay
    x2=np.append(-b/2, x2)
    x2=np.append(x2, b/2)

y2=(2*(h-h)/(b*b))*x2*x2-h/2
z2=(4*e/(b*b))*x2*x2+m+j+n

x3=np.arange(-(0.5*b+a), (-0.5*b+1), spacing_side_span)
if n_divisions_side1%1==0:
    pass
else:
    delay_side1=(a - math.floor(a/spacing_side_span) * spacing_side_span)
    x3=x3 + delay_side1
    x3=np.append(-(0.5*b+a), x3)

y3=-(g-h)/(2*a)*x3-(b*(g-h)/(4*a))+(h/2)
z3=d/a*x3+(e+b*d/(2*a))+m+j+n

x4=np.arange(-(0.5*b+a), (-0.5*b+1), spacing_side_span)
if n_divisions_side1%1==0:
    pass
else:
    delay_side1=(a - math.floor(a/spacing_side_span) * spacing_side_span)
    x4=x4 + delay_side1
    x4=np.append(-(0.5*b+a), x4)

y4=(g-h)/(2*a)*x4+(b*(g-h)/(4*a))-(h/2)
z4=d/a*x4+(e+b*d/(2*a))+m+j+n

x5=np.arange((0.5*b), (0.5*b+c+1), spacing_side_span)
if n_divisions_side2%1==0:
    pass
else:
    x5=np.append(x5, (0.5*b+c))

y5=(i-h)/(2*c)*x5-(b*(i-h)/(4*c))+(h/2)
z5=-f/c*x5+(e+b*f/(2*c))+m+j+n

x6=np.arange((0.5*b), (0.5*b+c+1), spacing_side_span)
if n_divisions_side2%1==0:
    pass
else:
    x6=np.append(x6, (0.5*b+c))

y6=-(i-h)/(2*c)*x6+b*(i-h)/(4*c)-(h/2)
z6=-f/c*x6+(e+b*f/(2*c))+m+j+n

# Join into two main cables
x3=np.delete(x3, -1)
x5=np.delete(x5, 0)
x1_main=np.append(x3, x1)
x1_main=np.append(x1_main, x5)  # x-vector cable 1
y3=np.delete(y3, -1)
y5=np.delete(y5, 0)
y1_main=np.append(y3, y1)
y1_main=np.append(y1_main, y5)  # y-vector cable 1
z3=np.delete(z3, -1)
z5=np.delete(z5, 0)
z1_main=np.append(z3, z1)
z1_main=np.append(z1_main, z5)  # z-vector cable 1
x4=np.delete(x4, -1)
x6=np.delete(x6, 0)
x2_main=np.append(x4, x2)
x2_main=np.append(x2_main, x6)  # x-vector cable 2
y4=np.delete(y4, -1)
y6=np.delete(y6, 0)
y2_main=np.append(y4, y2)
y2_main=np.append(y2_main, y6)  # y-vector cable 2
z4=np.delete(z4, -1)
z6=np.delete(z6,0)
z2_main=np.append(z4, z2)
z2_main=np.append(z2_main, z6)  # z-vector cable 2

cablelist1=list(zip(x1_main, y1_main, z1_main))
cablelist2=list(zip(x2_main, y2_main, z2_main))


# PYLONS/TOWERS
n_points_pylons=(j+n+m+e)/0.5+1
x7=np.linspace(-b/2,-b/2,n_points_pylons)
x8=np.linspace(b/2,b/2,n_points_pylons)
z7=np.linspace(0,e+j+n+m,n_points_pylons)
y7=np.linspace(k/2,h/2,n_points_pylons)
y8=np.linspace(-h/2,-k/2,n_points_pylons)

pylon1_x=np.append(x7, x7)
pylon1_y=np.append(y7, y8)
pylon1_z=np.append(z7, z7[::-1])
pylon1=list(zip(pylon1_x, pylon1_y, pylon1_z))

pylon2_x=np.append(x8, x8)
pylon2_y=np.append(y7, y8)
pylon2_z=np.append(z7, z7[::-1])
pylon2=list(zip(pylon2_x, pylon2_y, pylon2_z))



# GIRDER
x9=np.arange(-b/2+4, (b/2), spacing_girder)
n_divisions_girder=b/spacing_girder

if n_divisions_girder%1==0:
    pass
else:
    delay=(b - math.floor(b / spacing_girder) * spacing_girder) * 0.5
    x9=x9 + delay
    x9=np.append(-b/2, x9)
    x9=np.append(x9, b/2)

x9=np.append(-b/2, x9)
x9=np.append(x9, b/2)
y9=np.linspace(p/2,p/2,len(x9))
z9=-n/((b/2)**2)*(x9**2)+j+n

deck1=list(zip(x9, y9, z9))
deck2=list(zip(x9, y9-p, z9))

# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ INITIALIZATION ---------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
bridge=mdb.models['Model-1']
myAssembly=bridge.rootAssembly
myAssembly.DatumCsysByDefault(CARTESIAN)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TOWERS -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='Tower1', dimensionality=THREE_D, type=DEFORMABLE_BODY)
tower1=bridge.parts['Tower1']
tower1.WirePolyLine(points=pylon1[0:len(pylon1)/2], mergeType=SEPARATE, meshable=ON)
tower1.WirePolyLine(points=pylon1[len(pylon1)/2:], mergeType=SEPARATE, meshable=ON)

bridge.Part(name='Tower2', dimensionality=THREE_D, type=DEFORMABLE_BODY)
tower2=bridge.parts['Tower2']
tower2.WirePolyLine(points=pylon2[0:len(pylon2)/2], mergeType=SEPARATE, meshable=ON)
tower2.WirePolyLine(points=pylon2[len(pylon2)/2:], mergeType=SEPARATE, meshable=ON)

# PART SETS
set_tower1=bridge.parts['Tower1'].Set(name='Tower1 set', edges=tower1.edges)
set_tower2=bridge.parts['Tower2'].Set(name='Tower2 set', edges=tower2.edges)

# SECTION ASSIGNMENT
bridge.BoxProfile(name='profileTowers', a=12.5, b=14.5, uniformThickness=ON, t1=1.5)
Emat2=37000e6
Gmat2=Emat2/(2*(1+0.2))
my2ndsection=bridge.BeamSection(name='sectionTowers', profile='profileTowers', poissonRatio=0.2, integration=BEFORE_ANALYSIS,
    table=((Emat2, Gmat2), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
    consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
    temperatureDependency=OFF, thermalExpansion=OFF, density=2500.0)

bridge.parts['Tower1'].SectionAssignment(region=set_tower1, sectionName='sectionTowers')
bridge.parts['Tower1'].assignBeamSectionOrientation(region=set_tower1, method=N1_COSINES, n1=(0.0, 0.0, -1.0))
bridge.parts['Tower2'].SectionAssignment(region=set_tower2, sectionName='sectionTowers')
bridge.parts['Tower2'].assignBeamSectionOrientation(region=set_tower2, method=N1_COSINES, n1=(0.0, 0.0, -1.0))

# ASSEMBLY
inst_tower1=myAssembly.Instance(name='Tower1 instance', part=tower1, dependent=ON)
inst_tower2=myAssembly.Instance(name='Tower2 instance', part=tower2, dependent=ON)

# BCs
vert_tower1_bottoms=inst_tower1.vertices.findAt(((pylon1[0]), ), ((pylon1[-1]), ),)
vert_tower2_bottoms=inst_tower2.vertices.findAt(((pylon2[0]), ), ((pylon2[-1]), ),)

set_vert_tower1_bottoms=myAssembly.Set(name='setVertices Tower1_bottoms', vertices=vert_tower1_bottoms)
set_vert_tower2_bottoms=myAssembly.Set(name='setVertices Tower2_bottoms', vertices=vert_tower2_bottoms)

bridge.EncastreBC(createStepName='Initial', localCsys=None, name='towersbottomsBC1', region=set_vert_tower1_bottoms)
bridge.EncastreBC(createStepName='Initial', localCsys=None, name='towersbottomsBC2', region=set_vert_tower2_bottoms)

# MESH 
tower1.seedPart(size=sz_towers, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
tower1.setElementType(regions=set_tower1, elemTypes=(elemType1,))
tower1.generateMesh()
 
tower2.seedPart(size=sz_towers, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
tower2.setElementType(regions=set_tower2, elemTypes=(elemType1,))
tower2.generateMesh()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ RIGELS -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='Rigel1', dimensionality=THREE_D, type=DEFORMABLE_BODY)
rigel1=bridge.parts['Rigel1']
rigel1.WirePolyLine(points=((-b/2, h/2+((k-h)/2)*(n+m+e)/(j+n+m+e), j), (-0.5*b, p/2, j), (-0.5*b, -p/2, j), (-b/2, -h/2-((k-h)/2)*(n+m+e)/(j+n+m+e), j)), mergeType=IMPRINT, meshable=ON)

bridge.Part(name='Rigel2', dimensionality=THREE_D, type=DEFORMABLE_BODY)
rigel2=bridge.parts['Rigel2']
rigel2.WirePolyLine(points=((b/2, h/2+((k-h)/2)*(n+m+e)/(j+n+m+e), j), (0.5*b, p/2, j), (0.5*b, -p/2, j), (b/2, -h/2-((k-h)/2)*(n+m+e)/(j+n+m+e), j)), mergeType=IMPRINT, meshable=ON)

# PART SETS
set_rigel1=bridge.parts['Rigel1'].Set(name='Rigel1 set', edges=rigel1.edges)
set_rigel2=bridge.parts['Rigel2'].Set(name='Rigel2 set', edges=rigel2.edges)

# SECTION ASSIGNMENT
bridge.BoxProfile(name='profileRigels', a=8.0, b=5.0, uniformThickness=ON, t1=1.0)
Emat2=37000e6
Gmat2=Emat2/(2*(1+0.2))
my2ndsection=bridge.BeamSection(name='sectionRigels', profile='profileRigels', poissonRatio=0.2, integration=BEFORE_ANALYSIS,
    table=((Emat2, Gmat2), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
    consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
    temperatureDependency=OFF, thermalExpansion=OFF, density=2500.0)

bridge.parts['Rigel1'].SectionAssignment(region=set_rigel1, sectionName='sectionRigels')
bridge.parts['Rigel1'].assignBeamSectionOrientation(region=set_rigel1, method=N1_COSINES, n1=(0.0, 0.0, -1.0))
bridge.parts['Rigel2'].SectionAssignment(region=set_rigel2, sectionName='sectionRigels')
bridge.parts['Rigel2'].assignBeamSectionOrientation(region=set_rigel2, method=N1_COSINES, n1=(0.0, 0.0, -1.0))

# ASSEMBLY
inst_rigel1=myAssembly.Instance(name='Rigel1 instance', part=rigel1, dependent=ON)
inst_rigel2=myAssembly.Instance(name='Rigel2 instance', part=rigel2, dependent=ON)

# MESH 
rigel1.seedPart(size=sz_rigels, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
rigel1.setElementType(regions=set_rigel1, elemTypes=(elemType1,))
rigel1.generateMesh()
 
rigel2.seedPart(size=sz_rigels, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
rigel2.setElementType(regions=set_rigel2, elemTypes=(elemType1,))
rigel2.generateMesh()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ CABLES -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='Cable1', dimensionality=THREE_D, type=DEFORMABLE_BODY)
cable1=bridge.parts['Cable1']
cable1.WirePolyLine(points=cablelist1, mergeType=SEPARATE, meshable=ON)
bridge.Part(name='Cable2', dimensionality=THREE_D, type=DEFORMABLE_BODY)
cable2=bridge.parts['Cable2']
cable2.WirePolyLine(points=cablelist2, mergeType=SEPARATE, meshable=ON)

# PART SETS
set_cable1=bridge.parts['Cable1'].Set(name='Cable1 set', edges=cable1.edges)
set_cable2=bridge.parts['Cable2'].Set(name='Cable2 set', edges=cable2.edges)

# SECTION ASSIGNMENT
bridge.GeneralizedProfile(name='profileCables', area=0.6311, i11=0.03170, i12=0.00000, i22=0.03170, j=0.06340, gammaO=0.0,  gammaW=0.0)
Emat=200e9
Gmat=Emat/(2*(1+0.3))
mySection=bridge.BeamSection(name='sectionCables', profile='profileCables',                                    
    poissonRatio=0.3, integration=BEFORE_ANALYSIS,
    table=((Emat, Gmat), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
    consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
    temperatureDependency=OFF, thermalExpansion=OFF, density=7850.0)

bridge.parts['Cable1'].SectionAssignment(region=set_cable1, sectionName='sectionCables')
bridge.parts['Cable1'].assignBeamSectionOrientation(region=set_cable1, method=N1_COSINES, n1=(0.0, 1.0, 0.0))
bridge.parts['Cable2'].SectionAssignment(region=set_cable2, sectionName='sectionCables')
bridge.parts['Cable2'].assignBeamSectionOrientation(region=set_cable2, method=N1_COSINES, n1=(0.0, 1.0, 0.0))
    
# ASSEMBLY
inst_cable1=myAssembly.Instance(name='Cable1 instance', part=cable1, dependent=ON)
inst_cable2=myAssembly.Instance(name='Cable2 instance', part=cable2, dependent=ON)

# BCs
vert_cable1_anchorage=inst_cable1.vertices.findAt(((cablelist1[0]), ), ((cablelist1[-1]), ),) 
vert_cable2_anchorage=inst_cable2.vertices.findAt(((cablelist2[0]), ), ((cablelist2[-1]), ),)
vert_cable1_midspan=inst_cable1.vertices.findAt(((x1[np.argmin(z1)], y1[np.argmin(z1)], z1[np.argmin(z1)]), ),)
vert_cable2_midspan=inst_cable2.vertices.findAt(((x2[np.argmin(z2)], y2[np.argmin(z2)], z2[np.argmin(z2)]), ),)

set_vert_cable1_anchorage=myAssembly.Set(name='setVertices Cable1_Anchorage', vertices=vert_cable1_anchorage)
set_vert_cable1_midspan=myAssembly.Set(name='setVertices Cable1_Midspan', vertices=vert_cable1_midspan)
set_vert_cable2_anchorage=myAssembly.Set(name='setVertices Cable2_Anchorage', vertices=vert_cable2_anchorage)
set_vert_cable2_midspan=myAssembly.Set(name='setVertices Cable2_Midspan', vertices=vert_cable2_midspan)

bridge.PinnedBC(createStepName='Initial', localCsys=None, name='anchorageBC1', region=set_vert_cable1_anchorage)
constraint_midspan1=bridge.DisplacementBC(createStepName='Initial', name='midspanBC1', region=set_vert_cable1_midspan, u2=0)
bridge.PinnedBC(createStepName='Initial', localCsys=None, name='anchorageBC2', region=set_vert_cable2_anchorage)
constraint_midspan2=bridge.DisplacementBC(createStepName='Initial', name='midspanBC2', region=set_vert_cable2_midspan, u2=0)

# MESH
cable1.seedPart(size=sz_cables, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
cable1.setElementType(regions=set_cable1, elemTypes=(elemType1,))
cable1.generateMesh()

cable2.seedPart(size=sz_cables, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
cable2.setElementType(regions=set_cable2, elemTypes=(elemType1,))
cable2.generateMesh()

# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ GIRDER -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='Girder1', dimensionality=THREE_D, type=DEFORMABLE_BODY)
girder1=bridge.parts['Girder1']
girder1.WirePolyLine(points=deck1, mergeType=SEPARATE, meshable=ON)

bridge.Part(name='Girder2', dimensionality=THREE_D, type=DEFORMABLE_BODY)
girder2=bridge.parts['Girder2']
girder2.WirePolyLine(points=deck2, mergeType=SEPARATE, meshable=ON)

# PART SETS
set_girder1=bridge.parts['Girder1'].Set(name='Girder1 set', edges=girder1.edges)
set_girder2=bridge.parts['Girder2'].Set(name='Girder2 set', edges=girder2.edges)

# SECTION ASSIGNMENT
bridge.GeneralizedProfile(name='profileGirder', area=1.2338, i11=3.42, i12=0.0, i22=1.21e+2, j=9.42492, gammaO=0.0,  gammaW=0.0)             # STEEL
Emat3=Ematgirder
Gmat3=Emat3/(2*(1+0.3))
mySection=bridge.BeamSection(name='sectionGirder', profile='profileGirder',                                    
    poissonRatio=0.3, integration=BEFORE_ANALYSIS,
    table=((Emat3, Gmat3), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
    consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
    temperatureDependency=OFF, thermalExpansion=OFF, density=0.0)

bridge.parts['Girder1'].SectionAssignment(region=set_girder1, sectionName='sectionGirder')
bridge.parts['Girder1'].assignBeamSectionOrientation(region=set_girder1, method=N1_COSINES, n1=(0.0, 1.0, 0.0))
bridge.parts['Girder2'].SectionAssignment(region=set_girder2, sectionName='sectionGirder')
bridge.parts['Girder2'].assignBeamSectionOrientation(region=set_girder2, method=N1_COSINES, n1=(0.0, 1.0, 0.0))

# ASSEMBLY
inst_girder1=myAssembly.Instance(name='Girder1 instance', part=girder1, dependent=ON)
inst_girder2=myAssembly.Instance(name='Girder2 instance', part=girder2, dependent=ON)

# BCs
vert_girder1_ends=inst_girder1.vertices.findAt(((deck1[0]), ), ((deck1[-1]), ),) 
set_vert_girder1_ends=myAssembly.Set(name='setVertices Girder1_Ends', vertices=vert_girder1_ends)
vert_girder2_ends=inst_girder2.vertices.findAt(((deck2[0]), ), ((deck2[-1]), ),) 
set_vert_girder2_ends=myAssembly.Set(name='setVertices Girder2_Ends', vertices=vert_girder2_ends)

# MESH
girder1.seedPart(size=sz_girder, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B32)
girder1.setElementType(regions=set_girder1, elemTypes=(elemType1,))
girder1.generateMesh()

girder2.seedPart(size=sz_girder, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B32)
girder2.setElementType(regions=set_girder2, elemTypes=(elemType1,))
girder2.generateMesh()


# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ HANGERS ----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='Hanger1', dimensionality=THREE_D, type=DEFORMABLE_BODY)
hanger1=bridge.parts['Hanger1']

bridge.Part(name='Hanger2', dimensionality=THREE_D, type=DEFORMABLE_BODY)
hanger2=bridge.parts['Hanger2']

for i in range(len(VectorCoordX_girder)):
    res=function_nearest_vertice(cable1.vertices,(VectorCoordX_cable[i],0,VectorCoordZ_cable[i]),50)
    hanger1_node1=list(cable1.vertices[res[0]].pointOn[0])
    
    res=function_nearest_vertice(girder1.vertices,(VectorCoordX_girder[i],0,VectorCoordZ_girder[i]),50)
    hanger1_node2=list(girder1.vertices[res[0]].pointOn[0])
    hanger1_node2[1]=h/2
    hanger1_node2[-1]=hanger1_node2[-1]+1.5
    
    hanger1.WirePolyLine(points=(hanger1_node1, hanger1_node2), mergeType=IMPRINT, meshable=ON)
    
    res=function_nearest_vertice(cable2.vertices,(VectorCoordX_cable[i],0,VectorCoordZ_cable[i]),50)
    hanger2_node1=list(cable2.vertices[res[0]].pointOn[0])
    
    res=function_nearest_vertice(girder2.vertices,(VectorCoordX_girder[i],0,VectorCoordZ_girder[i]),50)
    hanger2_node2=list(girder1.vertices[res[0]].pointOn[0])
    hanger2_node2[1]=-h/2
    hanger2_node2[-1]=hanger2_node2[-1]+1.5
    
    hanger2.WirePolyLine(points=(hanger2_node1, hanger2_node2), mergeType=IMPRINT, meshable=ON)

# PART SETS
set_hanger1=bridge.parts['Hanger1'].Set(name='Hanger1 set', edges=hanger1.edges)
set_hanger2=bridge.parts['Hanger2'].Set(name='Hanger2 set', edges=hanger2.edges)

# SECTION ASSIGNMENT
bridge.GeneralizedProfile(name='profileHangers', area=0.006333, i11=3.192e-6, i12=0.0, i22=3.192e-6, j=6.384e-6, gammaO=0.0,  gammaW=0.0)
Emat=155e9
Gmat=Emat/(2*(1+0.3))
mySection=bridge.BeamSection(name='sectionHangers', profile='profileHangers',                                    
    poissonRatio=0.3, integration=BEFORE_ANALYSIS,
    table=((Emat, Gmat), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
    consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
    temperatureDependency=OFF, thermalExpansion=OFF, density=7850.0)
    
bridge.parts['Hanger1'].SectionAssignment(region=set_hanger1, sectionName='sectionHangers')
bridge.parts['Hanger1'].assignBeamSectionOrientation(region=set_hanger1, method=N1_COSINES, n1=(0.0, 1.0, 0.0))

bridge.parts['Hanger2'].SectionAssignment(region=set_hanger2, sectionName='sectionHangers')
bridge.parts['Hanger2'].assignBeamSectionOrientation(region=set_hanger2, method=N1_COSINES, n1=(0.0, 1.0, 0.0))

# ASSEMBLY
inst_hanger1=myAssembly.Instance(name='Hanger1 instance', part=hanger1, dependent=ON)
inst_hanger2=myAssembly.Instance(name='Hanger2 instance', part=hanger2, dependent=ON)

# MESH
elemType=mesh.ElemType(elemCode=B33)

hanger1.seedPart(size=sz_hangers, deviationFactor=0.01, minSizeFactor=0.01)
hanger1.setElementType(regions=set_hanger1, elemTypes=(elemType,))
hanger1.generateMesh()

hanger2.seedPart(size=sz_hangers, deviationFactor=0.01, minSizeFactor=0.01)
hanger2.setElementType(regions=set_hanger2, elemTypes=(elemType,))
hanger2.generateMesh()

myAssembly.regenerate()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ CONNECTION ELEMENTS TOWERS ---------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='ConelTowers', dimensionality=THREE_D, type=DEFORMABLE_BODY)
coneltowers=bridge.parts['ConelTowers']

for i in range(4):
    
    res=function_nearest_vertice(tower1.vertices,(-b/2,h/2,j+n+m+e-15-70*i),50)
    coneltower_node1=list(tower1.vertices[res[0]].pointOn[0])
    
    res=function_nearest_vertice(tower1.vertices,(-b/2,-h/2,j+n+m+e-15-70*i),50)
    coneltower_node2=list(tower1.vertices[res[0]].pointOn[0])
    
    coneltowers.WirePolyLine(points=(coneltower_node1, coneltower_node2), mergeType=IMPRINT, meshable=ON)
    
    res=function_nearest_vertice(tower2.vertices,(b/2,h/2,j+n+m+e-15-70*i),50)
    coneltower_node1=list(tower2.vertices[res[0]].pointOn[0])
    
    res=function_nearest_vertice(tower2.vertices,(b/2,-h/2,j+n+m+e-15-70*i),50)
    coneltower_node2=list(tower2.vertices[res[0]].pointOn[0])
    
    coneltowers.WirePolyLine(points=(coneltower_node1, coneltower_node2), mergeType=IMPRINT, meshable=ON)
    

# PART SETS
set_coneltowers=bridge.parts['ConelTowers'].Set(name='ConelTowers set', edges=coneltowers.edges)

# SECTION ASSIGNMENT
bridge.BoxProfile(name='profileConelTowers', a=8.0, b=5.0, uniformThickness=ON, t1=1.0)
Emat2=37000e6
Gmat2=Emat2/(2*(1+0.2))
my2ndsection=bridge.BeamSection(name='sectionConelTowers', profile='profileConelTowers', poissonRatio=0.2, integration=BEFORE_ANALYSIS,
    table=((Emat2, Gmat2), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
    consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
    temperatureDependency=OFF, thermalExpansion=OFF, density=2500.0)

bridge.parts['ConelTowers'].SectionAssignment(region=set_coneltowers, sectionName='sectionConelTowers')
bridge.parts['ConelTowers'].assignBeamSectionOrientation(region=set_coneltowers, method=N1_COSINES, n1=(0.0, 0.0, -1.0))

# ASSEMBLY
inst_coneltowers=myAssembly.Instance(name='ConelTowers instance', part=coneltowers, dependent=ON)

# MESH
coneltowers.seedPart(size=sz_coneltowers, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
coneltowers.setElementType(regions=set_coneltowers, elemTypes=(elemType1,))
coneltowers.generateMesh()
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ CONNECTION ELEMENTS GIRDER ---------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# PART CREATION
bridge.Part(name='ConelGirder', dimensionality=THREE_D, type=DEFORMABLE_BODY)
conelgirder=bridge.parts['ConelGirder']

for i in range(len(VectorCoordX_girder)):
    res=function_nearest_vertice(hanger1.vertices,(VectorCoordX_girder[i],0,VectorCoordZ_girder[i]),50)
    conelgirder_node1=list(hanger1.vertices[res[0]].pointOn[0])
    
    res=function_nearest_vertice(girder1.vertices,(VectorCoordX_girder[i],0,VectorCoordZ_girder[i]),50)
    conelgirder_node2=list(girder1.vertices[res[0]].pointOn[0])
    
    res=function_nearest_vertice(girder2.vertices,(VectorCoordX_girder[i],0,VectorCoordZ_girder[i]),50)
    conelgirder_node3=list(girder2.vertices[res[0]].pointOn[0])
    
    res=function_nearest_vertice(hanger2.vertices,(VectorCoordX_girder[i],0,VectorCoordZ_girder[i]),50)
    conelgirder_node4=list(hanger2.vertices[res[0]].pointOn[0])
    
    conelgirder.WirePolyLine(points=(conelgirder_node1, conelgirder_node2, conelgirder_node3, conelgirder_node4), mergeType=IMPRINT, meshable=ON)


# PART SETS
set_conelgirder=bridge.parts['ConelGirder'].Set(name='ConelGirder set', edges=conelgirder.edges)

# SECTION ASSIGNMENT
bridge.GeneralizedProfile(name='profileConelGirder', area=0.22, i11=1000.0, i12=0.0, i22=1000.0, j=1000.0, gammaO=0.0,  gammaW=0.0)
Emat3=2.00000e+11
Gmat3=Emat3/(2*(1+0.3))
mySection=bridge.BeamSection(name='sectionConelGirder', profile='profileConelGirder',                                    
    poissonRatio=0.3, integration=BEFORE_ANALYSIS,
    table=((Emat3, Gmat3), ), alphaDamping=0.0, beamShape=CONSTANT,
    betaDamping=0.0, centroid=(0.0, 0.0), compositeDamping=0.0,
    consistentMassMatrix=False, dependencies=0, shearCenter=(0.0, 0.0),
    temperatureDependency=OFF, thermalExpansion=OFF, density=0.0)

bridge.parts['ConelGirder'].SectionAssignment(region=set_conelgirder, sectionName='sectionConelGirder')
bridge.parts['ConelGirder'].assignBeamSectionOrientation(region=set_conelgirder, method=N1_COSINES, n1=(0.0, 0.0, -1.0))

# ASSEMBLY
inst_conelgirder=myAssembly.Instance(name='ConelGirders instance', part=conelgirder, dependent=ON)

# MESH
conelgirder.seedPart(size=sz_conelgirder, deviationFactor=0.01, minSizeFactor=0.01)
elemType1=mesh.ElemType(elemCode=B33)
conelgirder.setElementType(regions=set_conelgirder, elemTypes=(elemType1,))
conelgirder.generateMesh()   
        
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TIES ALONG GIRDERS -----------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------

for i in range(len(VectorCoordX_girder)):
    
    # Girder 1
    res=function_nearest_vertice(inst_girder1.vertices,(VectorCoordX_girder[i],h/2,VectorCoordZ_girder[i]),50)
    verticesMaster_girder1=res[3]
   
    res=function_nearest_vertice(inst_conelgirder.vertices,(VectorCoordX_girder[i],p/2,VectorCoordZ_girder[i]),50)
    verticesSlave_conelgirder1=res[3]
    
    setMaster_girder1=myAssembly.Set(name='Master_set_girder1 '+str(i).zfill(3), vertices=(verticesMaster_girder1))        
    setSlave_conelgirder1=myAssembly.Set(name='Slave_set_con1 '+str(i).zfill(3), vertices=(verticesSlave_conelgirder1))
    
    bridge.Tie(adjust=ON, master=setMaster_girder1, name='Constraint_con1_girder1_'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_conelgirder1, thickness=ON, tieRotations=ON)
    
    # Girder 2
    res=function_nearest_vertice(inst_girder2.vertices,(VectorCoordX_girder[i],-h/2,VectorCoordZ_girder[i]),50)
    verticesMaster_girder2=res[3]
    
    res=function_nearest_vertice(inst_conelgirder.vertices,(VectorCoordX_girder[i],-p/2,VectorCoordZ_girder[i]),50)
    verticesSlave_conelgirder2=res[3]
    
    setMaster_girder2=myAssembly.Set(name='Master_set_girder2 '+str(i).zfill(3), vertices=(verticesMaster_girder2))        
    setSlave_conelgirder2=myAssembly.Set(name='Slave_set_con2 '+str(i).zfill(3), vertices=(verticesSlave_conelgirder2))
    
    bridge.Tie(adjust=ON, master=setMaster_girder2, name='Constraint_con2_girder2_'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_conelgirder2, thickness=ON, tieRotations=ON)

# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TIES AT THE BOTTOM OF HANGERS ------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------

for i in range(len(VectorCoordX_girder)):
    
    # Cable 1
    res=function_nearest_vertice(inst_conelgirder.vertices,(VectorCoordX_girder[i],h/2,VectorCoordZ_girder[i]),50)
    verticesMaster_conelgirder=res[3]
    
    res=function_nearest_vertice(inst_hanger1.vertices,(VectorCoordX_girder[i],h/2,VectorCoordZ_girder[i]),50)
    verticesSlave_hanger1a=res[3]
    
    setMaster_conelgirder=myAssembly.Set(name='Master_set_con1 '+str(i).zfill(3), vertices=(verticesMaster_conelgirder))    
    setSlave_hanger1a=myAssembly.Set(name='Slave_set_hanger1a '+str(i).zfill(3), vertices=(verticesSlave_hanger1a))
    bridge.Tie(adjust=ON, master=setMaster_conelgirder, name='Constraint_hanger1_con1_'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_hanger1a, thickness=ON, tieRotations=ON)
    
    # Cable 2
    res=function_nearest_vertice(inst_conelgirder.vertices,(VectorCoordX_girder[i],-h/2,VectorCoordZ_girder[i]),50)
    verticesMaster_conelgirder=res[3]
    
    res=function_nearest_vertice(inst_hanger2.vertices,(VectorCoordX_girder[i],-h/2,VectorCoordZ_girder[i]),50)
    verticesSlave_hanger2a=res[3]
    
    setMaster_conelgirder=myAssembly.Set(name='Master_set_con2 '+str(i).zfill(3), vertices=(verticesMaster_conelgirder))    
    setSlave_hanger2a=myAssembly.Set(name='Slave_set_hanger2a '+str(i).zfill(3), vertices=(verticesSlave_hanger2a))
    bridge.Tie(adjust=ON, master=setMaster_conelgirder, name='Constraint_hanger2_con2_'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_hanger2a, thickness=ON, tieRotations=ON)
    
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TIES AT THE TOP OF HANGERS ---------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------    

for i in range(len(VectorCoordX_girder)):
    
    # Cable 1
    res=function_nearest_vertice(inst_cable1.vertices,(VectorCoordX_cable[i],h/2,VectorCoordZ_cable[i]),50)
    verticesMaster_cable1=res[3]
    
    res=function_nearest_vertice(inst_hanger1.vertices,(VectorCoordX_cable[i],h/2,VectorCoordZ_cable[i]),50)
    verticesSlave_hanger1b=res[3]
    
    setMaster_cable1=myAssembly.Set(name='Master_set_cable1 '+str(i).zfill(3), vertices=(verticesMaster_cable1))
    setSlave_hanger1b=myAssembly.Set(name='Slave_set_hanger1b '+str(i).zfill(3), vertices=(verticesSlave_hanger1b))
    bridge.Tie(adjust=ON, master=setMaster_cable1, name='Constraint_hanger1_cable1-'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_hanger1b, thickness=ON, tieRotations=ON)
    
    #Cable 2 
    res=function_nearest_vertice(inst_cable2.vertices,(VectorCoordX_cable[i],-h/2,VectorCoordZ_cable[i]),50)
    verticesMaster_cable2=res[3]
    
    res=function_nearest_vertice(inst_hanger2.vertices,(VectorCoordX_cable[i],-h/2,VectorCoordZ_cable[i]),50)
    verticesSlave_hanger2b=res[3]
    
    setMaster_cable2=myAssembly.Set(name='Master_set_cable2 '+str(i).zfill(3), vertices=(verticesMaster_cable2))
    setSlave_hanger2b=myAssembly.Set(name='Slave_set_hanger2b '+str(i).zfill(3), vertices=(verticesSlave_hanger2b))
    bridge.Tie(adjust=ON, master=setMaster_cable2, name='Constraint_hanger2_cable2-'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_hanger2b, thickness=ON, tieRotations=ON)
    
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TIES ALONG TOWERS ------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------

for i in range(4):
    
    # Connection elements tower 1
    res=function_nearest_vertice(inst_tower1.vertices,(-b/2,h/2,j+n+m+e-15-70*i),50)
    verticesMaster_tower1a=res[3]
    
    res=function_nearest_vertice(inst_coneltowers.vertices,(-b/2,h/2,j+n+m+e-15-70*i),50)
    verticesSlave_conel1tower1=res[3]
    
    setMaster_tower1a=myAssembly.Set(name='Master_set_tower1a '+str(i).zfill(3), vertices=(verticesMaster_tower1a))
    setSlave_conel1tower1=myAssembly.Set(name='Slave_set_conel1tower1 '+str(i).zfill(3), vertices=(verticesSlave_conel1tower1))
    bridge.Tie(adjust=ON, master=setMaster_tower1a, name='Constraint_tower1_con1-'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_conel1tower1, thickness=ON, tieRotations=ON)
    
    
    res=function_nearest_vertice(inst_tower1.vertices,(-b/2,-h/2,j+n+m+e-15-70*i),50)
    verticesMaster_tower1b=res[3]
    
    res=function_nearest_vertice(inst_coneltowers.vertices,(-b/2,-h/2,j+n+m+e-15-70*i),50)
    verticesSlave_conel2tower1=res[3]
    
    setMaster_tower1b=myAssembly.Set(name='Master_set_tower1b '+str(i).zfill(3), vertices=(verticesMaster_tower1b))
    setSlave_conel2tower1=myAssembly.Set(name='Slave_set_conel2tower1 '+str(i).zfill(3), vertices=(verticesSlave_conel2tower1))
    bridge.Tie(adjust=ON, master=setMaster_tower1b, name='Constraint_tower1_con2-'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_conel2tower1, thickness=ON, tieRotations=ON)   
    
    # Connection elements tower 2
    res=function_nearest_vertice(inst_tower2.vertices,(b/2,h/2,j+n+m+e-15-70*i),50)
    verticesMaster_tower2a=res[3]
    
    res=function_nearest_vertice(inst_coneltowers.vertices,(b/2,h/2,j+n+m+e-15-70*i),50)
    verticesSlave_conel1tower2=res[3]
    
    setMaster_tower2a=myAssembly.Set(name='Master_set_tower2a '+str(i).zfill(3), vertices=(verticesMaster_tower2a))
    setSlave_conel1tower2=myAssembly.Set(name='Slave_set_conel1tower2 '+str(i).zfill(3), vertices=(verticesSlave_conel1tower2))
    bridge.Tie(adjust=ON, master=setMaster_tower2a, name='Constraint_tower2_con1-'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_conel1tower2, thickness=ON, tieRotations=ON)
        
    res=function_nearest_vertice(inst_tower2.vertices,(b/2,-h/2,j+n+m+e-15-70*i),50)
    verticesMaster_tower2b=res[3]
    
    res=function_nearest_vertice(inst_coneltowers.vertices,(b/2,-h/2,j+n+m+e-15-70*i),50)
    verticesSlave_conel2tower2=res[3]
    
    setMaster_tower2b=myAssembly.Set(name='Master_set_tower2b '+str(i).zfill(3), vertices=(verticesMaster_tower2b))
    setSlave_conel2tower2=myAssembly.Set(name='Slave_set_conel2tower2 '+str(i).zfill(3), vertices=(verticesSlave_conel2tower2))
    bridge.Tie(adjust=ON, master=setMaster_tower2b, name='Constraint_tower2_con2-'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_conel2tower2, thickness=ON, tieRotations=ON)        

    

# Tower 1 to cable 1
res=function_nearest_vertice(inst_tower1.vertices,(-b/2,h/2,j+n+m+e),50)
verticesMaster_tower1_east=res[3]
    
res=function_nearest_vertice(inst_cable1.vertices,(-b/2,h/2,j+n+m+e),50)
verticesSlave_cable1_south=res[3]

setMaster_tower1_east=myAssembly.Set(name='Master_set_tower1_east', vertices=(verticesMaster_tower1_east))
setSlave_cable1_south=myAssembly.Set(name='Slave_set_cable1_south', vertices=(verticesSlave_cable1_south))
bridge.Tie(adjust=ON, master=setMaster_tower1_east, name='Constraint_tower1_cable1', positionToleranceMethod=SPECIFIED, 
    constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_cable1_south, thickness=ON, tieRotations=ON)

# Tower 1 to cable 2
res=function_nearest_vertice(inst_tower1.vertices,(-b/2,-h/2,j+n+m+e),50)
verticesMaster_tower1_west=res[3]

res=function_nearest_vertice(inst_cable2.vertices,(-b/2,-h/2,j+n+m+e),50)
verticesSlave_cable2_south=res[3]

setMaster_tower1_west=myAssembly.Set(name='Master_set_tower1_west', vertices=(verticesMaster_tower1_west))
setSlave_cable2_south=myAssembly.Set(name='Slave_set_cable2_south', vertices=(verticesSlave_cable2_south))
bridge.Tie(adjust=ON, master=setMaster_tower1_west, name='Constraint_tower1_cable2', positionToleranceMethod=SPECIFIED, 
constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_cable2_south, thickness=ON, tieRotations=ON)


# Tower 2 to cable 1
res=function_nearest_vertice(inst_tower2.vertices,(b/2,h/2,j+n+m+e),50)
verticesMaster_tower2_east=res[3]
    
res=function_nearest_vertice(inst_cable1.vertices,(b/2,h/2,j+n+m+e),50)
verticesSlave_cable1_north=res[3]

setMaster_tower2_east=myAssembly.Set(name='Master_set_tower2_east', vertices=(verticesMaster_tower2_east))
setSlave_cable1_north=myAssembly.Set(name='Slave_set_cable1_north', vertices=(verticesSlave_cable1_north))
bridge.Tie(adjust=ON, master=setMaster_tower2_east, name='Constraint_tower2_cable1', positionToleranceMethod=SPECIFIED, 
    constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_cable1_north, thickness=ON, tieRotations=ON)

# Tower 2 to cable 2
res=function_nearest_vertice(inst_tower2.vertices,(b/2,-h/2,j+n+m+e),50)
verticesMaster_tower2_west=res[3]

res=function_nearest_vertice(inst_cable2.vertices,(b/2,-h/2,j+n+m+e),50)
verticesSlave_cable2_north=res[3]

setMaster_tower2_west=myAssembly.Set(name='Master_set_tower2_west', vertices=(verticesMaster_tower2_west))
setSlave_cable2_north=myAssembly.Set(name='Slave_set_cable2_north', vertices=(verticesSlave_cable2_north))
bridge.Tie(adjust=ON, master=setMaster_tower2_west, name='Constraint_tower2_cable2', positionToleranceMethod=SPECIFIED, 
constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_cable2_north, thickness=ON, tieRotations=ON)
        
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ TIES ALONG RIGELS ------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------


for i in range(1):
    
    # Rigel 1
    res=function_nearest_vertice(inst_tower1.vertices,(-b/2,h/2,j),50)
    verticesMaster_tower1=res[3]
    
    res=function_nearest_vertice(inst_rigel1.vertices,(-b/2,h/2,j),50)
    verticesSlave_rigel1a=res[3]
    
    setMaster_tower1=myAssembly.Set(name='Master_set_tower1 '+str(i).zfill(3), vertices=(verticesMaster_tower1))
    setSlave_rigel1a=myAssembly.Set(name='Slave_set_rigel1a '+str(i).zfill(3), vertices=(verticesSlave_rigel1a))
    bridge.Tie(adjust=ON, master=setMaster_tower1, name='Constraint_tower1_rigel1-'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_rigel1a, thickness=ON, tieRotations=ON)
        
    res=function_nearest_vertice(inst_tower1.vertices,(-b/2,-h/2,j),50)
    verticesMaster_tower1=res[3]
    
    res=function_nearest_vertice(inst_rigel1.vertices,(-b/2,-h/2,j),50)
    verticesSlave_rigel1b=res[3]
    
    setMaster_tower1=myAssembly.Set(name='Master_set_tower1 '+str(i+1).zfill(3), vertices=(verticesMaster_tower1))
    setSlave_rigel1b=myAssembly.Set(name='Slave_set_rigel1b '+str(i+1).zfill(3), vertices=(verticesSlave_rigel1b))
    bridge.Tie(adjust=ON, master=setMaster_tower1, name='Constraint_tower1_rigel1-'+str(i+1).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_rigel1b, thickness=ON, tieRotations=ON)
        
    # Rigel 2
    res=function_nearest_vertice(inst_tower2.vertices,(b/2,h/2,j),50)
    verticesMaster_tower2=res[3]
    
    res=function_nearest_vertice(inst_rigel2.vertices,(b/2,h/2,j),50)
    verticesSlave_rigel2a=res[3]
    
    setMaster_tower2=myAssembly.Set(name='Master_set_tower2 '+str(i).zfill(3), vertices=(verticesMaster_tower2))
    setSlave_rigel2a=myAssembly.Set(name='Slave_set_rigel2a '+str(i).zfill(3), vertices=(verticesSlave_rigel2a))
    bridge.Tie(adjust=ON, master=setMaster_tower2, name='Constraint_tower2_rigel2-'+str(i).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_rigel2a, thickness=ON, tieRotations=ON)
        
    res=function_nearest_vertice(inst_tower2.vertices,(b/2,-h/2,j),50)
    verticesMaster_tower2=res[3]
    
    res=function_nearest_vertice(inst_rigel2.vertices,(b/2,-h/2,j),50)
    verticesSlave_rigel2b=res[3]
    
    setMaster_tower2=myAssembly.Set(name='Master_set_tower2 '+str(i+1).zfill(3), vertices=(verticesMaster_tower2))
    setSlave_rigel2b=myAssembly.Set(name='Slave_set_rigel2b '+str(i+1).zfill(3), vertices=(verticesSlave_rigel2b))
    bridge.Tie(adjust=ON, master=setMaster_tower2, name='Constraint_tower2_rigel2-'+str(i+1).zfill(3), positionToleranceMethod=SPECIFIED, 
        constraintEnforcement=NODE_TO_SURFACE, positionTolerance=100.0, slave=setSlave_rigel2b, thickness=ON, tieRotations=ON)

# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ EQUATION AND SPRING STIFFNESS AT GIRDER ENDS ---------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# RIGEL 1 TO GIRDER 1
res=function_nearest_vertice(inst_rigel1.vertices,(-b/2,p/2,j),50)
verticesMaster_rigel1c=res[3]
res=function_nearest_vertice(inst_girder1.vertices,(-b/2,p/2,j),50)
verticesSlave_girder1a=res[3]

setMaster=myAssembly.Set(name='Master_set 11', vertices=verticesMaster_rigel1c)
setSlave=myAssembly.Set(name='Slave_set 11', vertices=verticesSlave_girder1a)

# Constrained in z-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder1Rigel1z', regionPairs=region, axis=FIXED_DOF, dof1=3, dof2=3, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

# Constrained in y-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder1Rigel1y', regionPairs=region, axis=FIXED_DOF, dof1=2, dof2=2, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

# Constrained in y-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder1Rigel1r', regionPairs=region, axis=FIXED_DOF, dof1=4, dof2=4, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

# Horizontal translational spring at rigel1
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder1Rigel1x', regionPairs=region, axis=FIXED_DOF, dof1=1, dof2=1, 
    springBehavior=ON, springStiffness=1291200000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)
   
# RIGEL 2 TO GIRDER 1
res=function_nearest_vertice(inst_rigel2.vertices,(b/2,p/2,j),50)
verticesMaster_rigel2c=res[3]
res=function_nearest_vertice(inst_girder1.vertices,(b/2,p/2,j),50)
verticesSlave_girder1b=res[3]

setMaster=myAssembly.Set(name='Master_set 12', vertices=verticesMaster_rigel2c)
setSlave=myAssembly.Set(name='Slave_set 12', vertices=verticesSlave_girder1b)

# Constrained in z-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder1Rigel2z', regionPairs=region, axis=FIXED_DOF, dof1=3, dof2=3, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

# Constrained in y-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder1Rigel2y', regionPairs=region, axis=FIXED_DOF, dof1=2, dof2=2, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

# Constrained in y-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder1Rigel2r', regionPairs=region, axis=FIXED_DOF, dof1=4, dof2=4, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

#Horizontal translational spring at rigel2
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder1Rigel2x', regionPairs=region, axis=FIXED_DOF, dof1=1, dof2=1, 
    springBehavior=ON, springStiffness=1291200000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)
    
# RIGEL 1 TO GIRDER 2
res=function_nearest_vertice(inst_rigel1.vertices,(-b/2,-p/2,j),50)
verticesMaster_rigel1d=res[3]
res=function_nearest_vertice(inst_girder2.vertices,(-b/2,-p/2,j),50)
verticesSlave_girder2a=res[3]

setMaster=myAssembly.Set(name='Master_set 13', vertices=verticesMaster_rigel1d)
setSlave=myAssembly.Set(name='Slave_set 13', vertices=verticesSlave_girder2a)

# Constrained in z-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder2Rigel1z', regionPairs=region, axis=FIXED_DOF, dof1=3, dof2=3, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

# Constrained in y-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder2Rigel1y', regionPairs=region, axis=FIXED_DOF, dof1=2, dof2=2, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

# Constrained in y-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder2Rigel1r', regionPairs=region, axis=FIXED_DOF, dof1=4, dof2=4, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

#Horizontal translational spring at rigel1
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder2Rigel1x', regionPairs=region, axis=FIXED_DOF, dof1=1, dof2=1, 
    springBehavior=ON, springStiffness=1291200000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)
   
# RIGEL 2 TO GIRDER 2
res=function_nearest_vertice(inst_rigel2.vertices,(b/2,-p/2,j),50)
verticesMaster_rigel2d=res[3]
res=function_nearest_vertice(inst_girder2.vertices,(b/2,-p/2,j),50)
verticesSlave_girder2b=res[3]

setMaster=myAssembly.Set(name='Master_set 14', vertices=verticesMaster_rigel2d)
setSlave=myAssembly.Set(name='Slave_set 14', vertices=verticesSlave_girder2b)

# Constrained in z-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder2Rigel2z', regionPairs=region, axis=FIXED_DOF, dof1=3, dof2=3, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

# Constrained in y-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder2Rigel2y', regionPairs=region, axis=FIXED_DOF, dof1=2, dof2=2, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

# Constrained in y-direction
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder2Rigel2r', regionPairs=region, axis=FIXED_DOF, dof1=4, dof2=4, 
    springBehavior=ON, springStiffness=1000000000000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)

#Horizontal translational spring at rigel2
region=((setMaster, setSlave), )
myAssembly.engineeringFeatures.TwoPointSpringDashpot(
    name='Springs/Dashpots-Girder2Rigel2', regionPairs=region, axis=FIXED_DOF, dof1=1, dof2=1, 
    springBehavior=ON, springStiffness=1291200000.0, dashpotBehavior=OFF, 
    dashpotCoefficient=0.0)


# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ STEP 1 -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# Create step
bridge.StaticStep(name='step1', previous='Initial', nlgeom=OFF, initialInc=0.001, timePeriod=1, minInc=1e-7)  
bridge.FieldOutputRequest(name='F-Output-2', createStepName='step1', variables=('SF', 'U'), region=MODEL, frequency=1)

# TOWERS LOADING
edges1=inst_tower1.edges
edges2=inst_tower2.edges
set_edges_towers=myAssembly.Set(edges=edges1+edges2, name='SetEdges towers')
last1=bridge.Gravity(name='Gravity load towers', createStepName='step1', comp3=-9.81, distributionType=UNIFORM, field='', region=set_edges_towers)

# RIGELS LOADING
edges1=inst_rigel1.edges
edges2=inst_rigel2.edges
set_edges_rigels=myAssembly.Set(edges=edges1+edges2, name='SetEdges rigels')
last1=bridge.Gravity(name='Gravity load rigels', createStepName='step1', comp3=-9.81, distributionType=UNIFORM, field='', region=set_edges_rigels)

#model change, remove: cables, girder, hangers, conelgirder
edges1=inst_cable1.edges
edges2=inst_cable2.edges
edges3=inst_girder1.edges
edges4=inst_girder2.edges
edges5a=inst_hanger1.edges
edges5b=inst_hanger2.edges
edges7=inst_conelgirder.edges

set_modelchange1=myAssembly.Set(edges=edges1+edges2+edges3+edges4+edges5a+edges5b+edges7, name='Set-modelchange1')
mdb.models['Model-1'].ModelChange(name='modelchange step 1', createStepName='step1', region=set_modelchange1)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ STEP 2 -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# Create step
bridge.StaticStep(name='step2', previous='step1', nlgeom=ON, initialInc=0.001, timePeriod=1, minInc=1e-7, maxNumInc=500, matrixSolver=DIRECT)  
bridge.FieldOutputRequest(name='F-Output-2', createStepName='step2', variables=('SF', 'U'), region=MODEL) 

#model change, add: cables
edges1=inst_cable1.edges
edges2=inst_cable2.edges
set_modelchange2=myAssembly.Set(edges=edges1+edges2, name='Set-modelchange2')
mdb.models['Model-1'].ModelChange(name='modelchange step 2', createStepName='step2', region=set_modelchange2, activeInStep=ON)

# CABLE LOADING
edges1=inst_cable1.edges
edges2=inst_cable2.edges
set_edges_cables=myAssembly.Set(edges=edges1+edges2, name='SetEdges cables')
last2=bridge.Gravity(name='Gravity load cables', createStepName='step2', comp3=-9.81, distributionType=UNIFORM, field='', region=set_edges_cables)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ STEP 3 -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------

# Create step
bridge.StaticStep(name='step3', previous='step2', nlgeom=ON, initialInc=0.001, timePeriod=1, minInc=1e-7, maxNumInc=500, matrixSolver=DIRECT)  
bridge.FieldOutputRequest(name='F-Output-2', createStepName='step3', variables=('SF', 'U'), region=MODEL) 

#model change, add: girder, con.el.girder and hangers
edges1=inst_girder1.edges
edges2=inst_girder2.edges
edges3=inst_conelgirder.edges
edges4a=inst_hanger1.edges
edges4b=inst_hanger2.edges

set_modelchange3=myAssembly.Set(edges=edges1+edges2+edges3+edges4a+edges4b, name='Set-modelchange3')
mdb.models['Model-1'].ModelChange(name='modelchange step 3', createStepName='step3', region=set_modelchange3, activeInStep=ON)

# GIRDER LOADING 
set_edges_girder=myAssembly.Set(edges=edges1+edges2, name='SetEdges girder')
last3=bridge.Gravity(name='Gravity load girder', createStepName='step3', comp3=-9.81, distributionType=UNIFORM, field='', region=set_edges_girder)

# HANGERS LOADING 
edges1=inst_hanger1.edges
edges2=inst_hanger2.edges

set_edges_hangers=myAssembly.Set(edges=edges1+edges2, name='SetEdges hangers')
last4=bridge.Gravity(name='Gravity load hangers', createStepName='step3', comp3=-9.81, distributionType=UNIFORM, field='', region=set_edges_hangers)

# Remove the BC at the midspan of the bridge
constraint_midspan1.setValuesInStep(stepName='step3', u2=FREED)
constraint_midspan2.setValuesInStep(stepName='step3', u2=FREED)

# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ STEP 4 -----------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
bridge.FrequencyStep(name='stepModal', previous='step3', eigensolver=LANCZOS, numEigen=100)
bridge.FieldOutputRequest(name='F-Output-frequency', createStepName='stepModal', variables=('SF', 'U', 'COORD'), region=MODEL)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ NODE NUMBERING AND PATH ------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
a=mdb.models['Model-1'].rootAssembly

# GIRDER 1 (positive y-values)
a.makeIndependent(instances=(a.instances['Girder1 instance'], ))
partInstances=(a.instances['Girder1 instance'], )
a.setMeshNumberingControl(instances=partInstances, startNodeLabel=20001, 
    startElemLabel=20001)
session.Path(name='Path-girder1', type=NODE_LIST, expression=(('Girder1 instance', ('20001:20702', )), ))

# GIRDER 2 (negative y-values)
a.makeIndependent(instances=(a.instances['Girder2 instance'], ))
partInstances=(a.instances['Girder2 instance'], )
a.setMeshNumberingControl(instances=partInstances, startNodeLabel=10001, 
    startElemLabel=10001)
session.Path(name='Path-girder2', type=NODE_LIST, expression=(('Girder2 instance', ('10001:10702', )), ))

# CABLE 1 (positive y-values)
a.makeIndependent(instances=(a.instances['Cable1 instance'], ))
partInstances=(a.instances['Cable1 instance'], )
a.setMeshNumberingControl(instances=partInstances, startNodeLabel=40001, 
    startElemLabel=40001)
session.Path(name='Path-cable1', type=NODE_LIST, expression=(('Cable1 instance', ('40001:40172', )), ))

# CABLE 2 (negative y-values)
a.makeIndependent(instances=(a.instances['Cable2 instance'], ))
partInstances=(a.instances['Cable2 instance'], )
a.setMeshNumberingControl(instances=partInstances, startNodeLabel=30001, 
    startElemLabel=30001)
session.Path(name='Path-cable2', type=NODE_LIST, expression=(('Cable2 instance', ('30001:30172', )), ))

myAssembly.Set(name='Girder1 nodes', nodes=inst_girder1.nodes[:])
myAssembly.Set(name='Girder2 nodes', nodes=inst_girder2.nodes[:])

myAssembly.Set(name='Cable1 nodes', nodes=inst_cable1.nodes[:])
myAssembly.Set(name='Cable2 nodes', nodes=inst_cable2.nodes[:])

# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ ADD BEAM GIRDER INERTIA ------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------

mdb.models['Model-1'].keywordBlock.synchVersions(storeNodesAndElements=False)

# Girder 2 - e1 (second column) positive!

mdb.models['Model-1'].keywordBlock.insert(132, """
*BEAM ADDED INERTIA
6045.550,   0.000,      0.000,      0.,     5542.885,	    143309.600,     0. 
562.119,	0.000,	    0.000,      0.,     201.824,	    9034.565,       0.
2800.000,	2.234,	    1.287,      0.,     1.493,	        45733.333,      0.
33.333,	    9.234,	    1.047,      0.,     0.025,          0.025,          0.
191.125,	-6.141,	    0.000,      0.,     240.794,        120.449,       0.""")

# Girder 1 - e1 (second column) negative! 

mdb.models['Model-1'].keywordBlock.insert(123, """
*BEAM ADDED INERTIA
6045.550,   0.000,      0.000,      0.,     5542.885,	    143309.600,     0. 
562.119,	0.000,	    0.000,      0.,     201.824,	    9034.565,       0.
2800.000,	-2.234,	    1.287,      0.,     1.493,	        45733.333,      0.
33.333,	    -9.234,	    1.047,      0.,     0.025,          0.025,          0.
191.125,	6.141,	    0.000,      0.,     240.794,        120.449,       0.""")

"""
# From above
# 1: Steel girder
# 2: Steel diaphragmas
# 3: Asphalt
# 4: Hanger heads
# 5: Cross-beams
"""

# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ CREATE JOB -------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------
os.chdir(workDir)
myJob=mdb.Job(name=jobName, model='Model-1', multiprocessingMode=DEFAULT, numCpus=4, numDomains=4, numGPUs=0)
myJob.submit(consistencyChecking=OFF)
# -------------------------------------------------------------------------------------------------------------------------------------------------------
# ------------------------------------------------------------------ END --------------------------------------------------------------------------------
# -------------------------------------------------------------------------------------------------------------------------------------------------------