clc
clear all
close all
addpath('xxxx') % Add path to wawi toolbox
import wawi.*   
%% INPUT
InputPrefix='Sulafjorden_TD21_S1-G1_'; % Prefix in front of imported filenames 
%% Load abaqus results
nodecoord = load(strcat(InputPrefix,'nodecoord.txt'));
nodecoord_label = load(strcat(InputPrefix,'nodecoord_label.txt'));
ElementConnectivity2Nodes = load(strcat(InputPrefix,'ElementConnectivity2Node.txt'));
ElementConnectivity3Nodes = load(strcat(InputPrefix,'ElementConnectivity3Node.txt'));
%% Define elements with wind loads
elementsGirders = ElementConnectivity3Nodes(:,[1 2 4]);
elementsGirders = [elementsGirders ones(size(elementsGirders,1),1) ];
elementsCable = ElementConnectivity2Nodes(ElementConnectivity2Nodes(:,1)>30000,:);
elementsCable = [elementsCable 2*ones(size(elementsCable,1),1) ];
elements = [elementsGirders; elementsCable];
%% Get nodes
nodes = [nodecoord_label nodecoord];
%% modes
phi = load(strcat(InputPrefix,'phi.txt'));
%% Add mid girder
tmp = nodes(nodes(:,1)>10000,:); 
nodes_add1 = tmp(tmp(:,1)<20000,:);
tmp = nodes(nodes(:,1)>20000,:); 
nodes_add2 = tmp(tmp(:,1)<30000,:);
nodes_add = (nodes_add1 + nodes_add2)/2;
nodes_add(:,1) = nodes_add1(:,1) + 100000;
elements_add = elements(elements(:,1)<20000,:);
elements_add(:,1) = elements_add(:,1) + 100000;
elements_add(:,2) = elements_add(:,2) + 100000;
elements_add(:,3) = elements_add(:,3) + 100000;
elements = [elements; elements_add];
nodes = [nodes; nodes_add];
for k = 1:size(nodes_add,1)
    m = find(nodes(:,1)==nodes_add1(k,1));
    n = find(nodes(:,1)==nodes_add2(k,1));
    phim = phi(6*m-5:6*m,:);
    phin = phi(6*n-5:6*n,:);
    dist = nodes_add1(k,2:end)-nodes_add2(k,2:end);
    L = sqrt(dist*dist');
    phi_add(6*k-5:6*k,:) = (phim + phin)/2;
end
phi = [phi; phi_add];

%% Remove unused elements and nodes
[pos] = find(nodes(:,1)>29999);
nodes = nodes(pos,:);
phi_reduced = zeros(size(nodes,1)*6,size(phi,2));
for k = 1:length(pos)
    phi_reduced(6*k-5:6*k,:) = phi(6*pos(k,1)-5:6*pos(k,1),:);
end
phi = phi_reduced;
elements = elements(elements(:,1)>29999,:);

%% Wind direction
eV1 = [0 1 0]';
eV2p = [-1 0 0]';
TG2V = wawi.misc.transform_unit(eV1, eV2p);
TG2Le0 = zeros(3,3,size(elements,1));
for k = 1:size(elements,1)
    TG2Le0(:,:,k) = eye(3);    
end
%% Connectivity label2index
for k = 1:length(nodes)
    elements(elements(:,2)==nodes(k,1),2) = k;
    elements(elements(:,3)==nodes(k,1),3) = k;
end
%% Establish transformation matrix for elements
e2p =[0 1 0]';
for n=1:size(elements,1)
    X1=[nodes(elements(n,2),2) nodes(elements(n,2),3) nodes(elements(n,2),4)]'; %Element end 1
    X2=[nodes(elements(n,3),2) nodes(elements(n,3),3) nodes(elements(n,3),4)]'; %Element end 2
    L(n,1)=sqrt((X2-X1)'*(X2-X1));  %Length of element
    e1 = (X2-X1)./L(n,1);           %Unit vector in the direction of the element
    [TG2Le0(:,:,n)] = wawi.misc.transform_unit(e1, e2p); % Transform from global to loacal coordinates VLocal = TVGlobal
end
%% Plot nodes, elements and elementorientation
h1 = figure;
h2 = figure;
wawi.plot.plotwindelements(h1,h2,nodes,elements,TG2Le0,TG2V)
axis square
%% Plot selected modes
for i=2
    figure
    sk = 200;
    mode = i;
    tmp = max(abs([phi(1:6:end,mode); phi(2:6:end,mode); phi(3:6:end,mode)]));
    sk = sk/tmp;
    plot3(nodes(:,2),nodes(:,3),nodes(:,4),'o')
    hold on
    plot3(nodes(:,2)+sk*phi(1:6:end,mode),nodes(:,3)+sk*phi(2:6:end,mode),nodes(:,4)+sk*phi(3:6:end,mode),'o')
    axis([-1 1 -1 1 -1 1]*2000)
end
%% Generalized mass
Mg = load(strcat(InputPrefix,'genmass.txt'));
%% Natural frequencies 
f = load(strcat(InputPrefix,'freq.txt'));
%% Save 
save(strcat(InputPrefix,'AbaqusResults.mat'),'phi', 'f', 'Mg', 'nodes','elements','TG2Le0')




